import React, { EventHandler, SyntheticEvent } from 'react';
import cx from 'classnames';
import { IconButton } from '../button/IconButton';
import { iconTypes } from '../icon/iconTypes';
import styles from './itemActions.css';

type ItemActionsProps = {
  removeItem: () => void,
  className?: string
};

function stopPropagation (callback: EventHandler<SyntheticEvent>): EventHandler<SyntheticEvent> {
  return (event: SyntheticEvent) => {
    event.stopPropagation();
    callback(event);
  };
}

function ItemActions (props: ItemActionsProps) {
  const {
    className,
    removeItem
  } = props;

  return (
    <section className={cx(styles.itemActions, className)}>
      <IconButton icon={iconTypes.TRASH} buttonClassName={styles.button} onClick={stopPropagation(removeItem)} />
    </section>
  );
}

export {
  ItemActions
};
